from setuptools import find_packages, setup

name = 'errordetail'

setup(
    name=name,
    version='1.2.0',
    author="Jayson",
    author_email='jaysonteng@163.com',
    description="encapsulate logger",
    python_requires=">=3.*.*",
    packages=find_packages(),
    package_data={"": ["*"]},  # 数据文件全部打包
    include_package_data=True,  # 自动包含受版本控制(svn/git)的数据文件
    zip_safe=False,
)

"""
python setup.py sdist bdist_wheel
pip install twine
twine upload dist/*
"""


# -- coding: utf-8 --
import os
import sys
import time
import traceback


def get_error_detail(filename=None, title=None):
    error_info = sys.exc_info()
    if filename is None:
        filename = str(os.path.basename(sys.argv[0]))[:-3]
    with open(f'{filename}.errlog', 'a', encoding='utf8') as f:
        error_str = f'ERROR OCCURRED，{time.strftime("%Y-%m-%d %H:%M:%S")}：\n {error_info[0]}: {error_info[1]}'
        if title:
            print(f"{title}: \n{error_str}", file=f)
        else:
            print(error_str, file=f)  # 错误类型，错误概述
        traceback.print_tb(error_info[2], file=f)  # 错误细节描述
        f.write(f"{'=' * 50}\n")

